Reference
=========

pynotify.config
----------------------

.. automodule:: pynotify.config
    :members:
    :show-inheritance:

pynotify.dispatchers
---------------------------

.. automodule:: pynotify.dispatchers
    :members:
    :show-inheritance:

pynotify.exceptions
--------------------------

.. automodule:: pynotify.exceptions
    :members:
    :show-inheritance:

pynotify.handlers
------------------------

.. automodule:: pynotify.handlers
    :members:
    :show-inheritance:

pynotify.helpers
-----------------------

.. automodule:: pynotify.helpers
    :members:
    :show-inheritance:

pynotify.models
----------------------

.. automodule:: pynotify.models
    :members:
    :show-inheritance:

pynotify.notify
----------------------

.. automodule:: pynotify.notify
    :members:
    :show-inheritance:

pynotify.receivers
-------------------------

.. automodule:: pynotify.receivers
    :members:
    :show-inheritance:

pynotify.serializers
---------------------------

.. automodule:: pynotify.serializers
    :members:
    :show-inheritance:

pynotify.tasks
---------------------------

.. automodule:: pynotify.tasks
    :members:
    :show-inheritance:

    .. autofunction:: notification_task(self, *args, **kwargs)
